@@ -252,8 +252,31 @@ read.genalex <- function(genalex, ploidy = 2, geo = FALSE, region = FALSE,
   # Ensuring that all rows and columns have data
   data_rows <- apply(gena, 1, function(i) !all(is.na(i)))
   data_cols <- apply(gena, 2, function(i) !all(is.na(i)))
+  gcols <- colnames(gena)
+  dups  <- duplicated(gcols)
+  if (any(dups) && any(gcols[dups] != "")){
+    locations <- which(dups)
+    locations <- locations[gcols[dups] != ""]
+    colnames(gena) <- make.unique(gcols, sep = "_")
+    the_loci  <- gcols[dups & gcols != ""]
+    renamed   <- colnames(gena)[dups & gcols != ""]
+    msg <- "\n I found duplicate column names in your data.\n They are being renamed:\n"
+    renamed_data <- paste0("col ", locations, ": ", 
+                           the_loci, " -> ", renamed, collapse = "\n ")
+    msg <- paste(msg, renamed_data)
+    warning(msg, immediate. = TRUE)
+  }
   gena      <- gena[data_rows, data_cols]
-  
+  if (nrow(gena) != ninds) {
+    theData <- if (inherits(genalex, "character")) genalex else deparse(substitute(genalex))
+    msg <- paste0("\n The number of rows in your data do not match the number ",
+                 "of individuals specified.",
+                 "\n\t", ninds,      " individuals specified",
+                 "\n\t", nrow(gena), " rows in data",
+                 "\n Please inspect ", theData, " to ensure it's a properly ",
+                 "formatted GenAlEx file.\n")
+    stop(msg)
+  }
   #----------------------------------------------------------------------------#
   # Checking for extra information such as Regions or XY coordinates
   #----------------------------------------------------------------------------#
@@ -335,23 +358,36 @@ read.genalex <- function(genalex, ploidy = 2, geo = FALSE, region = FALSE,
   # Checking for greater than haploid data.
   if (nloci == clm/ploidy & ploidy > 1){
     # Missing data in genalex is coded as "0" for non-presence/absence data.
-    # this converts it to "NA" for adegenet.
-    if (any(gena.mat == "0", na.rm = TRUE) & ploidy < 3){
-      gena[gena.mat == "0"] <- NA
-    } else if (any(is.na(gena.mat)) & ploidy > 2) {
-      gena[is.na(gena.mat)] <- "0"
-    }
+    # We will convert these data later, but this will take care of the 
+    # data that's considered missing here
+    gena[is.na(gena.mat)] <- "0"
+    
     type  <- 'codom'
-    loci  <- which((1:clm) %% ploidy == 1)
+    # The remainder of the position when divided by ploidy is 1, which means
+    # that this is the first column starting the locus
+    loci  <- which(seq(clm) %% ploidy == 1)
     gena2 <- gena[, loci, drop = FALSE]
 
-    # Collapsing all alleles into single loci.
-    lapply(loci, function(x) gena2[, ((x-1)/ploidy)+1] <<-
-             pop_combiner(gena, hier = x:(x+ploidy-1), sep = "/"))
+    # Collapsing all alleles over all loci into their respective loci.
+    for (pos in loci){
+      # Get the locus position in gena2. Example, in a triploid, the second
+      # locus would be at gena[, 4:6], so the second element in pos would be 4
+      # because position %% ploidy is 4 %% 3 == 1
+      # We get our position out by:
+      #  1. subtracting 1 to account for the modulo
+      #  2. divide by ploidy
+      #  3. add 1 to bring it up to R's 1-index
+      pos_out <- ((pos - 1)/ploidy) + 1
+      pos_in  <- pos:(pos + ploidy - 1) # allele positions in gena
+      # paste columns of locus together
+      donor   <- do.call("paste", c(gena[pos_in], list(sep = "/")))
+      gena2[, pos_out] <- donor
+    }
 
     # Treating missing data.
     gena2[gena2 == paste(rep("0", ploidy), collapse = "/")] <- NA_character_
-    gena2[gena2 == paste(rep("NA", ploidy), collapse = "/")] <- NA_character_
+    
+    # Importing
     res.gid <- df2genind(gena2, sep="/", ind.names = ind.vec, pop = pop.vec,
                          ploidy = ploidy, type = type)
   } else if (nloci == clm & all(gena.mat %in% as.integer(-1:1))) {
@@ -366,7 +402,7 @@ read.genalex <- function(genalex, ploidy = 2, geo = FALSE, region = FALSE,
                          ploidy = ploidy, type = type, ncode = 1)
   } else if (nloci == clm & !all(gena.mat %in% as.integer(-1:1))) {
     # Checking for haploid microsatellite data or SNP data
-    if(any(gena.mat == "0", na.rm = TRUE)){
+    if (any(gena.mat == "0", na.rm = TRUE)){
       gena[gena.mat == "0"] <- NA
     }
     type    <- 'codom'
@@ -382,7 +418,12 @@ read.genalex <- function(genalex, ploidy = 2, geo = FALSE, region = FALSE,
                        ifelse(region,  
                        "You set region = TRUE. Do you have regional data in the right place?\n\n",
                        "If you have regional data: did you set the flag?\n\n"),
-                       "Otherwise, the problem may lie within the data structure itself.")
+                       "Otherwise, the problem may lie within the data structure itself.\n",
+                       " - Inspect your data; if it looks fine then\n",
+                       " - search the poppr forum for the error message; if you still can't find a solution:\n",
+                       "   1. Make a minimum working example of your error (see http://stackoverflow.com/a/5963610)\n",
+                       "   2. Use the 'reprex' package to reproduce the error (see https://github.com/jennybc/reprex#readme)\n",
+                       "   3. Create a new issue on https://github.com/grunwaldlab/poppr/issues")
     stop(weirdomsg)
   }
   if (any(duplicated(ind.vec))){
